# ape.types

## Address

```{eval-rst}
.. automodule:: ape.types.address
    :members: AddressType, RawAddress
```

## Signatures

```{eval-rst}
.. autoclass:: ape.types.signatures.SignableMessage
    :members:
    :show-inheritance:
```

```{eval-rst}
.. autoclass:: ape.types.signatures.MessageSignature
    :members:
    :show-inheritance:
```

```{eval-rst}
.. autoclass:: ape.types.signatures.TransactionSignature
    :members:
    :show-inheritance:
```

```{eval-rst}
.. automethod:: ape.types.signatures.recover_signer
```

## Coverage

```{eval-rst}
.. automodule:: ape.types.coverage
    :members:
    :show-inheritance:
```

## Miscellaneous

```{eval-rst}
.. automodule:: ape.types
    :members: BlockID, BaseContractLog, ContractLog, MockContractLog
```
